@@ -1,16 +1,23 @@
+##
+# name:      Spiffy
+# abstract:  Spiffy Perl Interface Framework For You
+# author:    Ingy döt Net <ingy@ingy.net>
+# license:   perl
+# copyright: 2004, 2006, 2011, 2012
+
 package Spiffy;
 use strict;
 use 5.006001;
 use warnings;
 use Carp;
 require Exporter;
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 our @EXPORT = ();
 our @EXPORT_BASE = qw(field const stub super);
 our @EXPORT_OK = (@EXPORT_BASE, qw(id WWW XXX YYY ZZZ));
 our %EXPORT_TAGS = (XXX => [qw(WWW XXX YYY ZZZ)]);
 
-my $stack_frame = 0; 
+my $stack_frame = 0;
 my $dump = 'yaml';
 my $bases_map = {};
 
@@ -37,7 +44,7 @@ sub new {
         my $method = shift;
         $self->$method(shift);
     }
-    return $self;    
+    return $self;
 }
 
 my $filtered_files = {};
@@ -45,7 +52,7 @@ my $filter_dump = 0;
 my $filter_save = 0;
 our $filter_result = '';
 sub import {
-    no strict 'refs'; 
+    no strict 'refs';
     no warnings;
     my $self_package = shift;
 
@@ -53,12 +60,12 @@ sub import {
     # subclass's boolean_arguments and paired_arguments can conflict, causing
     # difficult debugging. Consider using something truly local.
     my ($args, @export_list) = do {
-        local *boolean_arguments = sub { 
+        local *boolean_arguments = sub {
             qw(
-                -base -Base -mixin -selfless 
-                -XXX -dumper -yaml 
+                -base -Base -mixin -selfless
+                -XXX -dumper -yaml
                 -filter_dump -filter_save
-            ) 
+            )
         };
         local *paired_arguments = sub { qw(-package) };
         $self_package->parse_arguments(@_);
@@ -78,8 +85,8 @@ sub import {
           unless grep /^XXX$/, @EXPORT_BASE;
     }
 
-    spiffy_filter() 
-      if ($args->{-selfless} or $args->{-Base}) and 
+    spiffy_filter()
+      if ($args->{-selfless} or $args->{-Base}) and
          not $filtered_files->{(caller($stack_frame))[1]}++;
 
     my $caller_package = $args->{-package} || caller($stack_frame);
@@ -90,7 +97,7 @@ sub import {
         next unless $class->isa('Spiffy');
         my @export = grep {
             not defined &{"$caller_package\::$_"};
-        } ( @{"$class\::EXPORT"}, 
+        } ( @{"$class\::EXPORT"},
             ($args->{-Base} or $args->{-base})
               ? @{"$class\::EXPORT_BASE"} : (),
           );
@@ -98,7 +105,7 @@ sub import {
             not defined &{"$caller_package\::$_"};
         } @{"$class\::EXPORT_OK"};
 
-        # Avoid calling the expensive Exporter::export 
+        # Avoid calling the expensive Exporter::export
         # if there is nothing to do (optimization)
         my %exportable = map { ($_, 1) } @export, @export_ok;
         next unless keys %exportable;
@@ -162,7 +169,7 @@ sub base {
 sub all_my_bases {
     my $class = shift;
 
-    return $bases_map->{$class} 
+    return $bases_map->{$class}
       if defined $bases_map->{$class};
 
     my @bases = ($class);
@@ -174,10 +181,10 @@ sub all_my_bases {
     $bases_map->{$class} = [grep {not $used->{$_}++} @bases];
 }
 
-my %code = ( 
-    sub_start => 
+my %code = (
+    sub_start =>
       "sub {\n",
-    set_default => 
+    set_default =>
       "  \$_[0]->{%s} = %s\n    unless exists \$_[0]->{%s};\n",
     init =>
       "  return \$_[0]->{%s} = do { my \$self = \$_[0]; %s }\n" .
@@ -188,13 +195,13 @@ my %code = (
       "    Scalar::Util::weaken(\$_[0]->{%s}) if ref \$_[0]->{%s};\n" .
       "    \$_[0]->{%s};\n" .
       "  } unless \$#_ > 0 or defined \$_[0]->{%s};\n",
-    return_if_get => 
+    return_if_get =>
       "  return \$_[0]->{%s} unless \$#_ > 0;\n",
-    set => 
+    set =>
       "  \$_[0]->{%s} = \$_[1];\n",
-    weaken => 
+    weaken =>
       "  Scalar::Util::weaken(\$_[0]->{%s}) if ref \$_[0]->{%s};\n",
-    sub_end => 
+    sub_end =>
       "  return \$_[0]->{%s};\n}\n",
 );
 
@@ -228,7 +235,7 @@ sub field {
       if defined $default;
     $code .= sprintf $code{return_if_get}, $field;
     $code .= sprintf $code{set}, $field;
-    $code .= sprintf $code{weaken}, $field, $field 
+    $code .= sprintf $code{weaken}, $field, $field
       if $args->{-weak};
     $code .= sprintf $code{sub_end}, $field;
 
@@ -273,10 +280,10 @@ sub stub {
     $package = $args->{-package} if defined $args->{-package};
     no strict 'refs';
     return if defined &{"${package}::$field"};
-    *{"${package}::$field"} = 
-    sub { 
+    *{"${package}::$field"} =
+    sub {
         require Carp;
-        Carp::confess 
+        Carp::confess
           "Method $field in package $package must be subclassed";
     }
 }
@@ -300,7 +307,7 @@ sub parse_arguments {
             push @values, $elem;
         }
     }
-    return wantarray ? ($args, @values) : $args;        
+    return wantarray ? ($args, @values) : $args;
 }
 
 sub boolean_arguments { () }
@@ -324,8 +331,8 @@ sub id {
 package DB;
 {
     no warnings 'redefine';
-    sub super_args { 
-        my @dummy = caller(@_ ? $_[0] : 2); 
+    sub super_args {
+        my @dummy = caller(@_ ? $_[0] : 2);
         return @DB::args;
     }
 }
@@ -396,7 +403,7 @@ sub spiffy_base_import {
     my $inheritor = caller(0);
     for my $base_class (@base_classes) {
         next if $inheritor->isa($base_class);
-        croak "Can't mix Spiffy and non-Spiffy classes in 'use base'.\n", 
+        croak "Can't mix Spiffy and non-Spiffy classes in 'use base'.\n",
               "See the documentation of Spiffy.pm for details\n  "
           unless $base_class->isa('Spiffy');
         $stack_frame = 1; # tell import to use different caller
@@ -438,7 +445,7 @@ sub spiffy_mixin_methods {
         $methods{$_}
           ? ($_, \ &{"$methods{$_}\::$_"})
           : ($_, \ &{"$mixin_class\::$_"})
-    } @_ 
+    } @_
       ? (get_roles($mixin_class, @_))
       : (keys %methods);
 }
@@ -449,12 +456,12 @@ sub get_roles {
     while (grep /^!*:/, @roles) {
         @roles = map {
             s/!!//g;
-            /^!:(.*)/ ? do { 
-                my $m = "_role_$1"; 
+            /^!:(.*)/ ? do {
+                my $m = "_role_$1";
                 map("!$_", $mixin_class->$m);
             } :
             /^:(.*)/ ? do {
-                my $m = "_role_$1"; 
+                my $m = "_role_$1";
                 ($mixin_class->$m);
             } :
             ($_)
@@ -533,19 +540,13 @@ sub ZZZ {
 
 1;
 
-__END__
-
-=head1 NAME
-
-Spiffy - Spiffy Perl Interface Framework For You
-
 =head1 SYNOPSIS
 
     package Keen;
     use Spiffy -Base;
     field 'mirth';
     const mood => ':-)';
-    
+
     sub happy {
         if ($self->mood eq ':-(') {
             $self->mirth(-1);
@@ -557,41 +558,40 @@ Spiffy - Spiffy Perl Interface Framework For You
 =head1 DESCRIPTION
 
 "Spiffy" is a framework and methodology for doing object oriented (OO)
-programming in Perl. Spiffy combines the best parts of Exporter.pm,
-base.pm, mixin.pm and SUPER.pm into one magic foundation class. It
-attempts to fix all the nits and warts of traditional Perl OO, in a
-clean, straightforward and (perhaps someday) standard way.
+programming in Perl. Spiffy combines the best parts of Exporter.pm, base.pm,
+mixin.pm and SUPER.pm into one magic foundation class. It attempts to fix all
+the nits and warts of traditional Perl OO, in a clean, straightforward and
+(perhaps someday) standard way.
 
-Spiffy borrows ideas from other OO languages like Python, Ruby,
-Java and Perl 6. It also adds a few tricks of its own. 
+Spiffy borrows ideas from other OO languages like Python, Ruby, Java and Perl
+6. It also adds a few tricks of its own.
 
 If you take a look on CPAN, there are a ton of OO related modules. When
-starting a new project, you need to pick the set of modules that makes
-most sense, and then you need to use those modules in each of your
-classes. Spiffy, on the other hand, has everything you'll probably need
-in one module, and you only need to use it once in one of your classes.
-If you make Spiffy.pm the base class of the basest class in your
-project, Spiffy will automatically pass all of its magic to all of your
-subclasses. You may eventually forget that you're even using it!
+starting a new project, you need to pick the set of modules that makes most
+sense, and then you need to use those modules in each of your classes. Spiffy,
+on the other hand, has everything you'll probably need in one module, and you
+only need to use it once in one of your classes.  If you make Spiffy.pm the
+base class of the basest class in your project, Spiffy will automatically pass
+all of its magic to all of your subclasses. You may eventually forget that
+you're even using it!
 
-The most striking difference between Spiffy and other Perl object
-oriented base classes, is that it has the ability to export things.
-If you create a subclass of Spiffy, all the things that Spiffy
-exports will automatically be exported by your subclass, in addition to
-any more things that you want to export. And if someone creates a
-subclass of your subclass, all of those things will be exported
-automatically, and so on. Think of it as "Inherited Exportation", and it
-uses the familiar Exporter.pm specification syntax.
+The most striking difference between Spiffy and other Perl object oriented
+base classes, is that it has the ability to export things.  If you create a
+subclass of Spiffy, all the things that Spiffy exports will automatically be
+exported by your subclass, in addition to any more things that you want to
+export. And if someone creates a subclass of your subclass, all of those
+things will be exported automatically, and so on. Think of it as "Inherited
+Exportation", and it uses the familiar Exporter.pm specification syntax.
 
-To use Spiffy or any subclass of Spiffy as a base class of your class,
-you specify the C<-base> argument to the C<use> command. 
+To use Spiffy or any subclass of Spiffy as a base class of your class, you
+specify the C<-base> argument to the C<use> command.
 
     use MySpiffyBaseModule -base;
 
-You can also use the traditional C<use base 'MySpiffyBaseModule';>
-syntax and everything will work exactly the same. The only caveat is
-that Spiffy.pm must already be loaded. That's because Spiffy rewires
-base.pm on the fly to do all the Spiffy magics.
+You can also use the traditional C<use base 'MySpiffyBaseModule';> syntax and
+everything will work exactly the same. The only caveat is that Spiffy.pm must
+already be loaded. That's because Spiffy rewires base.pm on the fly to do all
+the Spiffy magics.
 
 Spiffy has support for Ruby-like mixins with Perl6-like roles. Just like
 C<base> you can use either of the following invocations:
@@ -599,38 +599,38 @@ C<base> you can use either of the following invocations:
     use mixin 'MySpiffyBaseModule';
     use MySpiffyBaseModule -mixin;
 
-The second version will only work if the class being mixed in is a
-subclass of Spiffy.  The first version will work in all cases, as long
-as Spiffy has already been loaded.
+The second version will only work if the class being mixed in is a subclass of
+Spiffy.  The first version will work in all cases, as long as Spiffy has
+already been loaded.
 
 To limit the methods that get mixed in, use roles. (Hint: they work just like
 an Exporter list):
 
     use MySpiffyBaseModule -mixin => qw(:basics x y !foo);
 
-In object oriented Perl almost every subroutine is a method. Each method
-gets the object passed to it as its first argument. That means
-practically every subroutine starts with the line:
+In object oriented Perl almost every subroutine is a method. Each method gets
+the object passed to it as its first argument. That means practically every
+subroutine starts with the line:
 
      my $self = shift;
 
-Spiffy provides a simple, optional filter mechanism to insert that line
-for you, resulting in cleaner code. If you figure an average method has
-10 lines of code, that's 10% of your code! To turn this option on, you
-just use the C<-Base> option instead of the C<-base> option, or add the
-C<-selfless> option. If source filtering makes you queazy, don't use the
-feature. I personally find it addictive in my quest for writing squeaky
-clean, maintainable code.
+Spiffy provides a simple, optional filter mechanism to insert that line for
+you, resulting in cleaner code. If you figure an average method has 10 lines
+of code, that's 10% of your code! To turn this option on, you just use the
+C<-Base> option instead of the C<-base> option, or add the C<-selfless>
+option. If source filtering makes you queazy, don't use the feature. I
+personally find it addictive in my quest for writing squeaky clean,
+maintainable code.
 
-A useful feature of Spiffy is that it exports two functions: C<field>
-and C<const> that can be used to declare the attributes of your class,
-and automatically generate accessor methods for them. The only
-difference between the two functions is that C<const> attributes can not
-be modified; thus the accessor is much faster.
+A useful feature of Spiffy is that it exports two functions: C<field> and
+C<const> that can be used to declare the attributes of your class, and
+automatically generate accessor methods for them. The only difference between
+the two functions is that C<const> attributes can not be modified; thus the
+accessor is much faster.
 
 One interesting aspect of OO programming is when a method calls the same
-method from a parent class. This is generally known as calling a super
-method. Perl's facility for doing this is butt ugly:
+method from a parent class. This is generally known as calling a super method.
+Perl's facility for doing this is butt ugly:
 
     sub cleanup {
         my $self = shift;
@@ -638,44 +638,41 @@ method. Perl's facility for doing this is butt ugly:
         $self->SUPER::cleanup(@_);
     }
 
-Spiffy makes it, er, super easy to call super methods. You just use
-the C<super> function. You don't need to pass it any arguments
-because it automatically passes them on for you. Here's the same
-function with Spiffy:
+Spiffy makes it, er, super easy to call super methods. You just use the
+C<super> function. You don't need to pass it any arguments because it
+automatically passes them on for you. Here's the same function with Spiffy:
 
     sub cleanup {
         $self->scrub;
         super;
     }
 
-Spiffy has a special method for parsing arguments called
-C<parse_arguments>, that it also uses for parsing its own arguments. You
-declare which arguments are boolean (singletons) and which ones are
-paired, with two special methods called C<boolean_arguments> and
-C<paired_arguments>. Parse arguments pulls out the booleans and pairs
-and returns them in an anonymous hash, followed by a list of the
-unmatched arguments.
+Spiffy has a special method for parsing arguments called C<parse_arguments>,
+that it also uses for parsing its own arguments. You declare which arguments
+are boolean (singletons) and which ones are paired, with two special methods
+called C<boolean_arguments> and C<paired_arguments>. Parse arguments pulls out
+the booleans and pairs and returns them in an anonymous hash, followed by a
+list of the unmatched arguments.
 
-Finally, Spiffy can export a few debugging functions C<WWW>, C<XXX>,
-C<YYY> and C<ZZZ>. Each of them produces a YAML dump of its arguments.
-WWW warns the output, XXX dies with the output, YYY prints the output,
-and ZZZ confesses the output. If YAML doesn't suit your needs, you can
-switch all the dumps to Data::Dumper format with the C<-dumper> option.
+Finally, Spiffy can export a few debugging functions C<WWW>, C<XXX>, C<YYY>
+and C<ZZZ>. Each of them produces a YAML dump of its arguments.  WWW warns the
+output, XXX dies with the output, YYY prints the output, and ZZZ confesses the
+output. If YAML doesn't suit your needs, you can switch all the dumps to
+Data::Dumper format with the C<-dumper> option.
 
 That's Spiffy!
 
 =head1 Spiffy EXPORTING
 
-Spiffy implements a completely new idea in Perl. Modules that act both
-as object oriented classes and that also export functions. But it
-takes the concept of Exporter.pm one step further; it walks the entire
-C<@ISA> path of a class and honors the export specifications of each
-module. Since Spiffy calls on the Exporter module to do this, you can
-use all the fancy interface features that Exporter has, including tags
-and negation.
+Spiffy implements a completely new idea in Perl. Modules that act both as
+object oriented classes and that also export functions. But it takes the
+concept of Exporter.pm one step further; it walks the entire C<@ISA> path of a
+class and honors the export specifications of each module. Since Spiffy calls
+on the Exporter module to do this, you can use all the fancy interface
+features that Exporter has, including tags and negation.
 
-Spiffy considers all the arguments that don't begin with a dash to
-comprise the export specification.
+Spiffy considers all the arguments that don't begin with a dash to comprise
+the export specification.
 
     package Vehicle;
     use Spiffy -base;
@@ -687,71 +684,68 @@ comprise the export specification.
     use Vehicle -base, '!field';
     $self->inflate(tire);
 
-In this case, C<Bicycle->isa('Vehicle')> and also all the things
-that C<Vehicle> and C<Spiffy> export, will go into C<Bicycle>,
-except C<field>.
+In this case, C<Bicycle->isa('Vehicle')> and also all the things that
+C<Vehicle> and C<Spiffy> export, will go into C<Bicycle>, except C<field>.
 
-Exporting can be very helpful when you've designed a system with
-hundreds of classes, and you want them all to have access to some
-functions or constants or variables. Just export them in your main base
-class and every subclass will get the functions they need.
+Exporting can be very helpful when you've designed a system with hundreds of
+classes, and you want them all to have access to some functions or constants
+    or variables. Just export them in your main base class and every subclass
+will get the functions they need.
 
-You can do almost everything that Exporter does because Spiffy delegates
-the job to Exporter (after adding some Spiffy magic). Spiffy offers a
-C<@EXPORT_BASE> variable which is like C<@EXPORT>, but only for usages
-that use C<-base>.
+You can do almost everything that Exporter does because Spiffy delegates the
+job to Exporter (after adding some Spiffy magic). Spiffy offers a
+C<@EXPORT_BASE> variable which is like C<@EXPORT>, but only for usages that
+use C<-base>.
 
 =head1 Spiffy MIXINs & ROLEs
 
 If you've done much OO programming in Perl you've probably used Multiple
-Inheritance (MI), and if you've done much MI you've probably run into
-weird problems and headaches. Some languages like Ruby, attempt to
-resolve MI issues using a technique called mixins. Basically, all Ruby
-classes use only Single Inheritance (SI), and then I<mixin>
-functionality from other modules if they need to.
+Inheritance (MI), and if you've done much MI you've probably run into weird
+problems and headaches. Some languages like Ruby, attempt to resolve MI issues
+using a technique called mixins. Basically, all Ruby classes use only Single
+Inheritance (SI), and then I<mixin> functionality from other modules if they
+need to.
 
-Mixins can be thought of at a simplistic level as I<importing> the
-methods of another class into your subclass. But from an implementation
-standpoint that's not the best way to do it. Spiffy does what Ruby
-does. It creates an empty anonymous class, imports everything into that
-class, and then chains the new class into your SI ISA path. In other
-words, if you say:
+Mixins can be thought of at a simplistic level as I<importing> the methods of
+another class into your subclass. But from an implementation standpoint that's
+not the best way to do it. Spiffy does what Ruby does. It creates an empty
+anonymous class, imports everything into that class, and then chains the new
+class into your SI ISA path. In other words, if you say:
 
-    package A;
-    use B -base;
-    use C -mixin;
-    use D -mixin;
+    package AAA;
+    use BBB -base;
+    use CCC -mixin;
+    use DDD -mixin;
 
 You end up with a single inheritance chain of classes like this:
 
-    A << A-D << A-C << B;
+    AAA << AAA-DDD << AAA-CCC << BBB;
 
-C<A-D> and C<A-C> are the actual package names of the generated
-classes. The nice thing about this style is that mixing in C doesn't
-clobber any methods in A, and D doesn't conflict with A or C either. If
-you mixed in a method in C that was also in A, you can still get to it
-by using C<super>.
+C<AAA-DDD> and C<AAA-CCC> are the actual package names of the generated
+classes. The nice thing about this style is that mixing in CCC doesn't clobber
+any methods in AAA, and DDD doesn't conflict with AAA or CCC either. If you
+mixed in a method in CCC that was also in AAA, you can still get to it by
+using C<super>.
 
-When Spiffy mixes in C, it pulls in all the methods in C that do not
-begin with an underscore. Actually it goes farther than that. If C is a
-subclass it will pull in every method that C C<can> do through
-inheritance. This is very powerful, maybe too powerful.
+When Spiffy mixes in CCC, it pulls in all the methods in CCC that do not begin
+with an underscore. Actually it goes farther than that. If CCC is a subclass
+it will pull in every method that CCC C<can> do through inheritance. This is
+very powerful, maybe too powerful.
 
-To limit what you mixin, Spiffy borrows the concept of Roles from
-Perl6. The term role is used more loosely in Spiffy though. It's much
-like an import list that the Exporter module uses, and you can use
-groups (tags) and negation. If the first element of your list uses
-negation, Spiffy will start with all the methods that your mixin
-class can do.
+To limit what you mixin, Spiffy borrows the concept of Roles from Perl6. The
+term role is used more loosely in Spiffy though. It's much like an import list
+that the Exporter module uses, and you can use groups (tags) and negation. If
+the first element of your list uses negation, Spiffy will start with all the
+methods that your mixin class can do.
 
-    use E -mixin => qw(:tools walk !run !:sharp_tools);
+    use EEE -mixin => qw(:tools walk !run !:sharp_tools);
 
-In this example, C<walk> and C<run> are methods that E can do, and
-C<tools> and C<sharp_tools> are roles of class E. How does class E
-define these roles? It very simply defines methods called C<_role_tools>
-and C<_role_sharp_tools> which return lists of more methods. (And
-possibly other roles!) The neat thing here is that since roles are just
-methods, they too can be inherited. Take B<that> Perl6!
+In this example, C<walk> and C<run> are methods that EEE can do, and C<tools>
+    and C<sharp_tools> are roles of class EEE. How does class EEE define these
+roles? It very simply defines methods called C<_role_tools> and
+C<_role_sharp_tools> which return lists of more methods. (And possibly other
+roles!) The neat thing here is that since roles are just methods, they too can
+be inherited. Take B<that> Perl6!
 
 =head1 Spiffy FILTERING
 
@@ -789,12 +783,12 @@ is exactly the same as:
     }
     ;1;
 
-Note that the empty parens after the subroutine C<new> keep it from
-having a $self added. Also note that the extra code is added to existing
-lines to ensure that line numbers are not altered.
+Note that the empty parens after the subroutine C<new> keep it from having a
+$self added. Also note that the extra code is added to existing lines to
+ensure that line numbers are not altered.
 
-C<-Base> also turns on the strict and warnings pragmas, and adds that
-annoying '1;' line to your module.
+C<-Base> also turns on the strict and warnings pragmas, and adds that annoying
+'1;' line to your module.
 
 =head1 PRIVATE METHODS
 
@@ -817,9 +811,9 @@ with a C<'$'> in front. Like this:
 
 =head1 Spiffy DEBUGGING
 
-The XXX function is very handy for debugging because you can insert it
-almost anywhere, and it will dump your data in nice clean YAML. Take the
-following statement:
+The XXX function is very handy for debugging because you can insert it almost
+anywhere, and it will dump your data in nice clean YAML. Take the following
+statement:
 
     my @stuff = grep { /keen/ } $self->find($a, $b);
 
@@ -831,9 +825,9 @@ following ways:
     my @stuff = grep { /keen/ } XXX $self->find($a, $b);
     my @stuff = grep { /keen/ } $self->find(XXX $a, $b);
 
-XXX is easy to insert and remove. It is also a tradition to mark
-uncertain areas of code with XXX. This will make the debugging dumpers
-easy to spot if you forget to take them out.
+XXX is easy to insert and remove. It is also a tradition to mark uncertain
+areas of code with XXX. This will make the debugging dumpers easy to spot if
+you forget to take them out.
 
 WWW and YYY are nice because they dump their arguments and then return the
 arguments. This way you can insert them into many places and still have the
@@ -841,8 +835,8 @@ code run as before. Use ZZZ when you need to die with both a YAML dump and a
 full stack trace.
 
 The debugging functions are exported by default if you use the C<-base>
-option, but only if you have previously used the C<-XXX> option. To
-export all 4 functions use the export tag:
+option, but only if you have previously used the C<-XXX> option. To export all
+4 functions use the export tag:
 
     use SomeSpiffyModule ':XXX';
 
@@ -853,8 +847,8 @@ To force the debugging functions to use Data::Dumper instead of YAML:
 =head1 Spiffy FUNCTIONS
 
 This section describes the functions the Spiffy exports. The C<field>,
-C<const>, C<stub> and C<super> functions are only exported when you use
-the C<-base> or C<-Base> options.
+C<const>, C<stub> and C<super> functions are only exported when you use the
+C<-base> or C<-Base> options.
 
 =over 4
 
@@ -864,7 +858,7 @@ Defines accessor methods for a field of your class:
 
     package Example;
     use Spiffy -Base;
-    
+
     field 'foo';
     field bar => [];
 
@@ -873,35 +867,33 @@ Defines accessor methods for a field of your class:
         push @{$self->{bar}}, $self->foo;
     }
 
-The first parameter passed to C<field> is the name of the attribute
-being defined. Accessors can be given an optional default value.
-This value will be returned if no value for the field has been set
-in the object.
+The first parameter passed to C<field> is the name of the attribute being
+defined. Accessors can be given an optional default value.  This value will be
+returned if no value for the field has been set in the object.
 
 =item * const
 
     const bar => 42;
 
-The C<const> function is similar to <field> except that it is immutable.
-It also does not store data in the object. You probably always want to
-give a C<const> a default value, otherwise the generated method will be
-somewhat useless.
+The C<const> function is similar to <field> except that it is immutable.  It
+also does not store data in the object. You probably always want to give a
+C<const> a default value, otherwise the generated method will be somewhat
+useless.
 
 =item * stub
 
     stub 'cigar';
 
-The C<stub> function generates a method that will die with an
-appropriate message. The idea is that subclasses must implement these
-methods so that the stub methods don't get called.
+The C<stub> function generates a method that will die with an appropriate
+message. The idea is that subclasses must implement these methods so that the
+stub methods don't get called.
 
 =item * super
 
-If this function is called without any arguments, it will call the same
-method that it is in, higher up in the ISA tree, passing it all the
-same arguments. If it is called with arguments, it will use those
-arguments with C<$self> in the front. In other words, it just works
-like you'd expect.
+If this function is called without any arguments, it will call the same method
+that it is in, higher up in the ISA tree, passing it all the same arguments.
+If it is called with arguments, it will use those arguments with C<$self> in
+the front. In other words, it just works like you'd expect.
 
     sub foo {
         super;             # Same as $self->SUPER::foo(@_);
@@ -915,8 +907,8 @@ like you'd expect.
         return $self;
     }
 
-C<super> will simply do nothing if there is no super method. Finally,
-C<super> does the right thing in AUTOLOAD subroutines.
+C<super> will simply do nothing if there is no super method. Finally, C<super>
+does the right thing in AUTOLOAD subroutines.
 
 =back
 
@@ -929,19 +921,19 @@ automatically inherits.
 
 =item * mixin
 
-A method to mixin a class at runtime. Takes the same arguments as C<use
-mixin ...>. Makes the target class a mixin of the caller.
+A method to mixin a class at runtime. Takes the same arguments as C<use mixin
+...>. Makes the target class a mixin of the caller.
 
     $self->mixin('SomeClass');
     $object->mixin('SomeOtherClass' => 'some_method');
 
 =item * parse_arguments
 
-This method takes a list of arguments and groups them into pairs. It
-allows for boolean arguments which may or may not have a value
-(defaulting to 1). The method returns a hash reference of all the pairs
-as keys and values in the hash. Any arguments that cannot be paired, are
-returned as a list. Here is an example:
+This method takes a list of arguments and groups them into pairs. It allows
+for boolean arguments which may or may not have a value (defaulting to 1). The
+method returns a hash reference of all the pairs as keys and values in the
+hash. Any arguments that cannot be paired, are returned as a list. Here is an
+example:
 
     sub boolean_arguments { qw(-has_spots -is_yummy) }
     sub paired_arguments { qw(-name -size) }
@@ -979,14 +971,13 @@ this method to define your own list.
 
 =head1 Spiffy ARGUMENTS
 
-When you C<use> the Spiffy module or a subclass of it, you can pass it a
-list of arguments. These arguments are parsed using the
-C<parse_arguments> method described above. The special argument 
-C<-base>, is used to make the current package a subclass of the Spiffy
-module being used.
+When you C<use> the Spiffy module or a subclass of it, you can pass it a list
+of arguments. These arguments are parsed using the C<parse_arguments> method
+described above. The special argument C<-base>, is used to make the current
+package a subclass of the Spiffy module being used.
 
-Any non-paired parameters act like a normal import list; just like those
-used with the Exporter module.
+Any non-paired parameters act like a normal import list; just like those used
+with the Exporter module.
 
 =head1 USING Spiffy WITH base.pm
 
@@ -998,25 +989,25 @@ would want to C<use base>.
     use Spiffy::Module -base;
     use base 'NonSpiffy::Module';
 
-Now it may be hard to keep track of what's Spiffy and what is not.
-Therefore Spiffy has actually been made to work with base.pm. You can
-say:
+Now it may be hard to keep track of what's Spiffy and what is not. Therefore
+Spiffy has actually been made to work with base.pm. You can say:
 
     package Something;
     use base 'Spiffy::Module';
     use base 'NonSpiffy::Module';
 
 C<use base> is also very useful when your class is not an actual module (a
-separate file) but just a package in some file that has already been loaded.
-C<base> will work whether the class is a module or not, while the C<-base>
-syntax cannot work that way, since C<use> always tries to load a module.
+separate file) but just a package in some file that has already been
+loaded.  C<base> will work whether the class is a module or not, while the
+C<-base> syntax cannot work that way, since C<use> always tries to load a
+module.
 
 =head2 base.pm Caveats
 
 To make Spiffy work with base.pm, a dirty trick was played. Spiffy swaps
 C<base::import> with its own version. If the base modules are not Spiffy,
-Spiffy calls the original base::import. If the base modules are Spiffy,
-then Spiffy does its own thing.
+Spiffy calls the original base::import. If the base modules are Spiffy, then
+Spiffy does its own thing.
 
 There are two caveats.
 
@@ -1024,43 +1015,24 @@ There are two caveats.
 
 =item * Spiffy must be loaded first.
 
-If Spiffy is not loaded and C<use base> is invoked on a Spiffy module,
-Spiffy will die with a useful message telling the author to read this
-documentation. That's because Spiffy needed to do the import swap
-beforehand.
+If Spiffy is not loaded and C<use base> is invoked on a Spiffy module, Spiffy
+will die with a useful message telling the author to read this documentation.
+That's because Spiffy needed to do the import swap beforehand.
 
-If you get this error, simply put a statement like this up front in
-your code:
+If you get this error, simply put a statement like this up front in your code:
 
     use Spiffy ();
 
 =item * No Mixing
 
-C<base.pm> can take multiple arguments. And this works with Spiffy as
-long as all the base classes are Spiffy, or they are all non-Spiffy. If
-they are mixed, Spiffy will die. In this case just use separate C<use
-base> statements.
+C<base.pm> can take multiple arguments. And this works with Spiffy as long as
+all the base classes are Spiffy, or they are all non-Spiffy. If they are
+mixed, Spiffy will die. In this case just use separate C<use base> statements.
 
 =back
 
 =head1 Spiffy TODO LIST
 
-Spiffy is a wonderful way to do OO programming in Perl, but it is still
-a work in progress. New things will be added, and things that don't work
-well, might be removed.
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2006. Ingy döt Net. All rights reserved.
-Copyright (c) 2004. Brian Ingerson. All rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See L<http://www.perl.com/perl/misc/Artistic.html>
-
-=cut
+Spiffy is a wonderful way to do OO programming in Perl, but it is still a work
+in progress. New things will be added, and things that don't work well, might
+be removed.
